"""PDF set commads."""
from typing import Optional
import typer
from toolbox.sets.pdf.converter import convert_pdf_to_docx, convert_pdf_to_selectable
from toolbox.common.output import show_message, abort
from toolbox.common.exceptions import ConvertPDFException

app = typer.Typer(short_help="PDF CLI Tool")


@app.command()
def convert_to_selectable_pdf(input_file: str, output_file: Optional[str] = typer.Argument(None)):
    """Converts a scan PDF file to selectable PDF."""
    try:
        convert_pdf_to_selectable(input_file, output_file)
    except ConvertPDFException as err:
        abort(f'Error converting to selectable pdf: {err}')
    show_message("File converted successfully[green].")


@ app.command()
def convert_to_docx(input_file: str, output_file: Optional[str] = typer.Argument(None)):
    """Converts a PDF file to a DOCX file."""
    try:
        convert_pdf_to_docx(input_file, output_file)
    except ConvertPDFException as err:
        abort(f'Error converting to docx: {err}')
    show_message("File converted successfully[green].")



"""Business set commands."""
import datetime
import typer
from toolbox.common.work import get_month_working_hours, get_month_working_days
from toolbox.common.output import show_message

app = typer.Typer(short_help="Business CLI Tool")


@app.command()
def working_hours(
        is_month: bool = typer.Option(False, '--this-month',
                                      help="Get current month working hours.", is_flag=True)):
    """Get working hours based of a date period."""
    year = datetime.datetime.now().year
    if is_month:
        month = datetime.datetime.now().month
        month_working_hours = get_month_working_hours(month, year)
        show_message(f"Current month working hours: {month_working_hours}")


@app.command()
def working_days(
    is_month: bool = typer.Option(False, '--this-month',
                                  help="Get current month working days.", is_flag=True)):
    """Get working days based of a date period."""
    year = datetime.datetime.now().year
    if is_month:
        month = datetime.datetime.now().month
        month_working_days = get_month_working_days(month, year)
        show_message(f"Current month working days: {month_working_days}")



"""Module for work."""
import numpy as np
from toolbox.common.calendar import get_first_date_of_month, get_last_date_of_month


def get_month_working_days(month: int, year: int) -> int:
    """Get the number of working days for a given month.

    Args:
        month (int): Month of the year.
        year (int): Year of the month.
    """
    start_date = get_first_date_of_month(year, month)
    end_date = get_last_date_of_month(year, month)
    return np.busday_count(start_date, end_date) + 1


def get_month_working_hours(month: int, year: int) -> int:
    """Get the number of working hours for a given month.

    Args:
        month (int): Month of the year.
        year (int): Year of the month.
    """
    return get_month_working_days(month, year) * 8
